%% SCRIPT FOR ANALYSIS ON THE CREATED DATASETS MAPS

% Julia Gala de Pablo
% PhD Student
% University of Leeds


%% FILE IMPORTING
clear all
close all
clc

dirPath='C:\SavingPathExample';
addpath('C:\MatlabFunctionsPath'); % For any additional functions

% Name of the particular experiment for the dataset imported
NameSaving{1}='Map1_';
NameSaving{2}='Map2_';

% Specify if the map is raster (1) or snake (0)
raster(1:100)=ones(1,100);

NameFinalData='_datasetanalysed';

selectedDatasets=[1,2];

fprintf('Loading the Data \n')
tic
FileName={};
m=1;
RamanSpectra={};
RamanBackgroundSpectra={};
DataMatrix=[];
Average={};
Error={};
Allindex=[];

for j=selectedDatasets
    fprintf(['Loading data from dataset' num2str(j) '\n']);
    cd(dirPath{j});
    % Loading Data Matrix
    analTemp=load([NameSaving{j} NameFinalData '.mat']);
    DataMatrix=[DataMatrix analTemp.DataMatrix];
    index{j}=(1:size(analTemp.DataMatrix,2))+(size(DataMatrix,2)-size(analTemp.DataMatrix,2));
    Average{j}=analTemp.Average;
    Error{j}=analTemp.Error; % just the std, not the standar error
    Xposition{j}=analTemp.Xposition;
    Yposition{j}=analTemp.Yposition;
    Xintvalues=analTemp.Xintvalues;
    Allindex=[Allindex index{j}];
    clear rawTemp analTemp
end
toc


%% Standarizing the data

% SNV (Standar Normal Variate) normalizes the standar deviation of each spectra to 1. It is
% calculated as:

% SNV = (Data - Average)/Standar deviation

% However, bear in mind that Matlab pca funcion already standarizes the data.

RamanSpectraAverage=mean(DataMatrix,1);
RamanSpectraSTD=std(DataMatrix,0,1);

% Doing it in matrix form to save some computing time
DataMatrixNorm=(DataMatrix-repmat(RamanSpectraAverage,size(DataMatrix,1),1))./repmat(RamanSpectraSTD,size(DataMatrix,1),1);

%% Plot the average and the Standard deviation of each group of data

figure
count=1;
for j=selectedDatasets
   subplot(2,3,count)
   xlabel('Wavenumber (cm^{-1})')
   ylabel('Raman Intensity (counts)')
   axis tight
   box on
   xlim([min(Xintvalues)+2 max(Xintvalues)-2])
   title(NameSaving{j})
   hold on
   plot(Xintvalues,mean(DataMatrix(:,index{j}),2),'k')
   plot(Xintvalues,mean(DataMatrix(:,index{j}),2)+std(DataMatrix(:,index{j}),0,2),'-r')
   plot(Xintvalues,mean(DataMatrix(:,index{j}),2)-std(DataMatrix(:,index{j}),0,2),'-r')
   count=count+1;
end

%% Plot the individual spectra

figure
count=1;
for j=selectedDatasets
   subplot(2,3,count)
   xlabel('Wavenumber (cm^{-1})')
   ylabel('Raman Intensity (counts)')
   axis tight
   box on
   xlim([min(Xintvalues)+2 max(Xintvalues)-2])
   title(NameSaving{j})
   for k=index{j}(1:10:end)
       hold on
       plot(Xintvalues,DataMatrix(:,k),'k')
   end
   count=count+1;
end

%% PCA
[coeff,score,latent,tsquared,explained,mu]=pca((DataMatrix(:,:).'));
explained(1:5)

%% Plot variance explained

figure(100)
subplot(1,2,1)
bar(explained,0.9,'k')
xlim([0.5 10.5])
xlabel('Components')
ylabel('Variance explained (%)')
subplot(1,2,2)
plot(cumsum(explained),'sk-')
xlabel('Components')
ylabel('Cumulative Variance explained (%)')
xlim([0.5 100.5])
toc

%% Plot the components

fprintf('Plotting the main 3 first components \n')
coeffToPlot=4;
tic
figure(5)
offsetValue=0.25;

c=colormap('jet');
colors=c(1:floor(64/coeffToPlot):end,:);
count=1;
LegendString={};

for j=1:coeffToPlot
    hold on
    plot(Xintvalues,coeff(:,j)+offsetValue*(count-1),'Color',colors(j,:))
    LegendString{count}=['PC' num2str(j)];
    count=count+1;
end

ylim([-offsetValue*1 offsetValue*count])
xlim([min(Xintvalues) max(Xintvalues)])
box on
xlabel('Wavenumber / cm^{-1}')
ylabel('Raman Intensity / Offset')
toc
axis tight

%% Show the pca results as images

for j=selectedDatasets
    Xmin{j}=min(Xposition{j});
    Xmax{j}=max(Xposition{j});
    Ymin{j}=min(Yposition{j});
    Ymax{j}=max(Yposition{j});
    % Assuming that the step is always the same
    Xstep{j}=Xposition{j}(2)-Xposition{j}(1);
    % Assume that the step is the same in X and Y
    Ystep{j}=Xstep{j};
    % Length of each axis matrix
    Xlength{j}=int16((Xmax{j}-Xmin{j})/Xstep{j})+1;
    Ylength{j}=int16((Ymax{j}-Ymin{j})/Ystep{j})+1;
    Yunique{j}=unique(Yposition{j},'stable');

    % Turn data into a square matrix

    % Prealocating for speed
    scoreImageMatrix{j}=NaN(Ylength{j},Xlength{j},10);%,size(score,2));
    LengthRow{j}=zeros(length(Yunique{j}),1);
    Rowstart{j}=zeros(length(Yunique{j}),1);
    
    scoreTemp=score(index{j},:);
    
    for k=1:10%length(score)
        for i=1:length(Yunique{j})
            LengthRow{j}(i)=sum(Yposition{j}==Yunique{j}(i));
            CumLengthRow{j}=cumsum(LengthRow{j});
            % The beginning of the row would be the middle of the length of the
            % row minus half the length of the row
            % Be careful because we are doing snake and not raster!!! (shit)
            Rowstart{j}(i)=round((Xlength{j}-LengthRow{j}(i))/2)+1;
            if i==1
                scoreImageMatrix{j}(i,Rowstart{j}(i):Rowstart{j}(i)+LengthRow{j}(i)-1,k)=...
                    scoreTemp(1:LengthRow{j}(i),k).';
            elseif mod(i,2)==1
                scoreImageMatrix{j}(i,Rowstart{j}(i):Rowstart{j}(i)+LengthRow{j}(i)-1,k)=...
                    scoreTemp(CumLengthRow{j}(i-1)+1:CumLengthRow{j}(i-1)+LengthRow{j}(i),k).';        
            else
                if raster(j)==0
                    scoreImageMatrix{j}(i,Rowstart{j}(i):Rowstart{j}(i)+LengthRow{j}(i)-1,k)=...
                        flip(scoreTemp(CumLengthRow{j}(i-1)+1:CumLengthRow{j}(i-1)+LengthRow{j}(i),k)).';   
                elseif raster(j)==1
                    scoreImageMatrix{j}(i,Rowstart{j}(i):Rowstart{j}(i)+LengthRow{j}(i)-1,k)=...
                        scoreTemp(CumLengthRow{j}(i-1)+1:CumLengthRow{j}(i-1)+LengthRow{j}(i),k).';               
                end                 
            end
        end
    end
    
    %% Show the map
    figure
    colormap('hot')
    for k=1:10
        subplot(3,4,k)
        imagesc(scoreImageMatrix{j}(:,:,k))
        caxis([prctile(score(Allindex,k),[1 99])])
        title(num2str(k))
        colorbar
        axis equal
    end
    waitforbuttonpress
    
    %% Save images as gray 1-99 LUT images to be able to plot them in imageJ
    figure
    for k=1:coeffToPlot
        % Changing the magnification x10 (100% x 10 = 1000) to get 10
        % pixels per normal pixel.
        imshow(scoreImageMatrix{j}(:,:,k),'Border','tight','InitialMagnification',1000)
        colormap 'gray'
        caxis([prctile(score(Allindex,k),[1 99])])
        %axis off
        %axis image
        cd(dirPath{j})
        set(gcf,'PaperPositionMode','auto')
        print([NameSaving{j} '_All_Score1-99_PC' num2str(k) '.tif'],'-dtiff','-r0')
    end
    close all
end

%% Show the histograms of the components
percentileLimits=[95 100];
for j=selectedDatasets
    figure
    hold on
    for k=1:coeffToPlot
        subplot(2,3,k)
        hist(score(index{j},k))
        title(strcat('PC',num2str(k)))
        yl=ylim;
        PctTemp=prctile(score(:,k),percentileLimits);
        line([PctTemp(1) PctTemp(1)],yl)
        line([PctTemp(2) PctTemp(2)],yl)
    end
end

% Show the average spectra per component when only considering the pixels 
% that have high scores

AveragePC=zeros(size(DataMatrix,1),coeffToPlot);
Offset=25;
count=0;
for k=1:coeffToPlot
    figure
    subplot(2,1,1)
    lim=prctile(score(:,k),percentileLimits);
    CutoffTemp=and(score(:,k)>lim(1),score(:,k)<lim(2));
    AveragePC(:,k)=mean(DataMatrix(:,CutoffTemp),2);
    plot(Xintvalues,AveragePC(:,k))
    title(strcat('PC',num2str(k)))
    clear CutoffTemp
    count=count+1;
    subplot(2,1,2)
    maskTemp=and(scoreImageMatrix{selectedDatasets}(:,:,k)>lim(1),scoreImageMatrix{selectedDatasets}(:,:,k)<lim(2));
    imagesc(maskTemp)
    axis image
    clear markTemp
end
xlabel('Wavenumber / cm^{-1}')
ylabel('Average Raman Intensity')
axis tight
box on
legend('PC1','PC2','PC3','PC4')


%% Calculating the correlation matrices and turning that into images
% Of the DataMatrix
% To use the function corrcoef the columns are variables (shift values) and
% the rows are observations (cell numbers), so we need to use the
% transposed matrix
[CorrelationMatrix PvalueMatrix]=corrcoef(DataMatrix.');

% I want to save a Correlation matrix where we only have the points whose
% p-value is smaller than 1e-4 (significant), and changes those points into
% 0 if not
CorrelationMatrixP=CorrelationMatrix;
for i=1:size(PvalueMatrix,1)
    for j=1:size(PvalueMatrix,1)
        if i>j
            if PvalueMatrix(i,j)>=1e-4
                CorrelationMatrixP(i,j)=0;
                CorrelationMatrixP(j,i)=0;
            end
        end
    end
end

% I want to save a Correlation matrix where only correlations whose
% absolute value is >=0.3 are shown (like a mask of it).
CorrelationMatrixF=CorrelationMatrix;
for i=1:size(CorrelationMatrixF,1)
    for j=1:size(CorrelationMatrixF,1)
        if i>j
            if abs(CorrelationMatrixF(i,j))<0.2
                CorrelationMatrixF(i,j)=0;
                CorrelationMatrixF(j,i)=0;
            end
        end
    end
end
    

%% Now we want to show it as an image - Correlation Matrix

figure(1005)
colormap('gray')
imagesc(CorrelationMatrix,[-0.5 0.5])
colorbar
g=gca;
xlabel('Wavenumber / cm^{-1}')
ylabel('Wavenumber / cm^{-1}')
axis square

tickincrease=200;
set(gca, 'Xtick',1:tickincrease:length(Xintvalues))
set(gca, 'Xticklabel',Xintvalues(1:tickincrease:end))
set(gca, 'XticklabelRotation',90)
set(gca, 'Ytick',1:tickincrease:length(Xintvalues))
set(gca, 'Yticklabel',Xintvalues(1:tickincrease:end))

line([2503 2503],[0 length(Xintvalues)],'Color','w','Linewidth',2)
line([0 length(Xintvalues)],[2503 2503],'Color','w','Linewidth',2)

print(figure(1005),['CorrelationMatrix' '.tif'],'-dtiff','-r600')

%% Now we want to show it as an image - CorrelationMatrixP

figure(1006)
colormap('gray')
imagesc(CorrelationMatrixP,[-0.5 0.5])
colorbar
g=gca;
xlabel('Wavenumber / cm^{-1}')
ylabel('Wavenumber / cm^{-1}')
axis square

tickincrease=200;
set(gca, 'Xtick',1:tickincrease:length(Xintvalues))
set(gca, 'Xticklabel',Xintvalues(1:tickincrease:end))
set(gca, 'XticklabelRotation',90)
set(gca, 'Ytick',1:tickincrease:length(Xintvalues))
set(gca, 'Yticklabel',Xintvalues(1:tickincrease:end))

line([2503 2503],[0 length(Xintvalues)],'Color','w','Linewidth',2)
line([0 length(Xintvalues)],[2503 2503],'Color','w','Linewidth',2)

print(figure(1006),['CorrelationMatrixP' '.tif'],'-dtiff','-r600')

%% Now we want to show it as an image - CorrelationMatrixF

figure(1007)
colormap('gray')
imagesc(CorrelationMatrixF,[-0.3 0.3])
colorbar
g=gca;
xlabel('Wavenumber / cm^{-1}')
ylabel('Wavenumber / cm^{-1}')
axis square

tickincrease=200;
set(gca, 'Xtick',1:tickincrease:length(Xintvalues))
set(gca, 'Xticklabel',Xintvalues(1:tickincrease:end))
set(gca, 'XticklabelRotation',90)
set(gca, 'Ytick',1:tickincrease:length(Xintvalues))
set(gca, 'Yticklabel',Xintvalues(1:tickincrease:end))

line([2503 2503],[0 length(Xintvalues)],'Color','w','Linewidth',2)
line([0 length(Xintvalues)],[2503 2503],'Color','w','Linewidth',2)

print(figure(1007),['CorrelationMatrixF' '.tif'],'-dtiff','-r600')

%% Plot them
Offset=1.5;
figure(400)

% ValuesToPlot=[741.5,747.5,754,757.5];
ValuesToPlot=[1294,1338,1373,1434,1445,1490,1596,1627,1632,1656,1672,1727,2195];

count=0;
for j=ValuesToPlot%(3)
    hold on
    indextemp=find(j==Xintvalues,1);
    a=plot(Xintvalues,CorrelationMatrix(:,indextemp)+Offset*count,'c');
    b=plot(Xintvalues,CorrelationMatrixP(:,indextemp)+Offset*count,'k');
    %Lines
    line([Xintvalues(1) Xintvalues(end)],[count*Offset count*Offset],'Color','k')
    
    axis tight
    xlim([min(Xintvalues) 1750])
    xlabel('Wavenumber / cm^{-1})')
    ylabel('Correlation (Offset)')
    
    % Find peaks and label them
    [Peak, PeakIdx] = findpeaks(CorrelationMatrix(:,indextemp),'MinPeakProminence',0.2,'MinPeakHeight',0.2); 
    for i=1:length(Peak)
        text(Xintvalues(PeakIdx(i)), Peak(i)+Offset*count*1.02,...
            sprintf('%6.1f', Xintvalues(PeakIdx(i))),'Rotation',90);
    end    
    plot(Xintvalues(PeakIdx), Peak+Offset*count,'ok')
    count=count+1;
end

axis tight
yl = ylim;
ylim([yl(1) yl(2)+Offsetplot*0.3])

legend([a,b],{'Correlation','p-value corrected Correlation (p<0.0001)'})

%% Plot them as a draggable figure so we can see the correlation in each point by clicking on it
Offset=0;
figure(400)

while 1==1
    subplot(2,1,1)
    AverageAll=mean(DataMatrix,2);
    plot(Xintvalues,AverageAll,'k')
    hold on
    xlim([Xintvalues(1) Xintvalues(end)])
    [j,y] = ginput(1);
    plot(j,AverageAll(find(round(j)==Xintvalues,1)),'ok')
    
    subplot(2,1,2)
    indextemp=find(round(j)==Xintvalues,1);
    plotCorr{count+1}=plot(Xintvalues,CorrelationMatrixP(:,indextemp)+Offset*count);
    hold on
    line([Xintvalues(1) Xintvalues(end)],[0.3+count*Offset 0.3+count*Offset],'Color','k')
    line([Xintvalues(1) Xintvalues(end)],[-0.3+count*Offset -0.3+count*Offset],'Color','r')
    xlabel('Shift (cm^{-1})')
    ylabel('Correlation (Offset)')

    % Find peaks and label them
    [Peak, PeakIdx] = findpeaks(CorrelationMatrixP(:,indextemp),'MinPeakProminence',0.1,'MinPeakHeight',0.1); 
    for i=1:length(Peak)
        text(Xintvalues(PeakIdx(i)), Peak(i)+Offset*count, sprintf('%6.1f', Xintvalues(PeakIdx(i))));
    end    
    plot(Xintvalues(PeakIdx), Peak+Offset*count,'ok')

    legend(num2str(j))
    xlim([Xintvalues(1) Xintvalues(end)])
    hold off
end


%% k-means cluster
% We might want to implement k-means cluster to try to obtain a nicer image
% when using multiple colors. If we want to reflect more than 3 groups of
% observations overlayed in the same image, then we need to do this. We
% loose the intensity values, but we obtain a more faithful representations
% of the clusters present in the image.
clear ClusterVector
disp('Performing k-cluster analysis')
ClusterNumber=10;
Component1=1;
ExplainThreshold=25;
KlusterComponents=[Component1:ExplainThreshold];

% Calculate a normalized score matrix
% scoreNorm=(score-repmat(min(score),size(score,1),1))./repmat(max(score)-min(score),size(score,1),1);


[ClusterVector,C,sumd]=kmeans(score(:,[KlusterComponents]),ClusterNumber,...
    'Start','cluster','MaxIter',500,'Display','final','Replicates',5);

c=colormap('hsv');
ColorStep=1:length(c)/ClusterNumber:length(c);
cS=c(round(ColorStep),:);

% Order the clusters by the score in a certain PC, for example PC1
% Calculate the mean score for that Cluster in PC1
ClusterSortingNumber=1;
clear ClusterMean
for i=1:ClusterNumber
    ClusterMean(i)=mean(score(ClusterVector==i,ClusterSortingNumber));
end
clear ClusterVectorSorted IndexSort
[~,IndexSort]=sort(ClusterMean);
ClusterVectorSorted=zeros(size(ClusterVector));
for i=1:length(IndexSort)
    ClusterVectorTemp=i.*(ClusterVector==IndexSort(i));
    ClusterVectorSorted=ClusterVectorSorted+ClusterVectorTemp;
    clear ClusterVectorTemp
end

% Might want to look at the PCA to choose the number of clusters
figure
pc=Component1+[0,1,2,3,4,5];
for i=1:ClusterNumber
    subplot(1,2,1)
    hold on
    scatter3(score(ClusterVectorSorted==i,pc(1)),score(ClusterVectorSorted==i,pc(2)),...
        score(ClusterVectorSorted==i,pc(3)),'filled','MarkerFaceColor',cS(i,:))
    view(3)
    box on
    subplot(1,2,2)
    hold on
    scatter3(score(ClusterVectorSorted==i,pc(4)),score(ClusterVectorSorted==i,pc(5)),...
        score(ClusterVectorSorted==i,pc(6)),'filled','MarkerFaceColor',cS(i,:))   
    view(3)
    box on
end

subplot(1,2,1)
xlabel(strcat('PC',num2str(pc(1))))
ylabel(strcat('PC',num2str(pc(2))))
zlabel(strcat('PC',num2str(pc(3))))
axis square
axis tight

subplot(1,2,2)
xlabel(strcat('PC',num2str(pc(4))))
ylabel(strcat('PC',num2str(pc(5))))
zlabel(strcat('PC',num2str(pc(6))))
axis square
axis tight

legend('Cluster 1',...
    'Cluster 2',...
    'Cluster 3',...
    'Cluster 4',...
    'Cluster 5',...
    'Location','best');

% Plot the average for each of the clusters
Offset=1;
figure(100)
for i=1:ClusterNumber
    hold on
    plot(Xintvalues,mean(DataMatrixNorm(:,ClusterVectorSorted==i)+Offset*i,2),'Color',cS(i,:))
    axis tight
    xlabel('Wavenumber (cm^{-1})')
    ylabel('Average Intensity (SNV)')
    box on
end

print(figure(100),['All_' 'clusterShapes' num2str(ClusterNumber) '.tif'],'-dtiff','-r200')

% Show the cluster results as images
figure
count=1;
for j=selectedDatasets
    % As none of the images are snake and all are rectangular, we can simplify
    % this code to:
    clusterImageMatrix{j}=vec2mat(ClusterVectorSorted(index{j}),LengthRow{j}(1));
    if raster==0
        for i=2:2:size(ClusterVectorSorted(index{j}),1)
            clusterImageMatrix{j}(i,:)=flipr(clusterImageMatrix{j}(i,:));
        end
    end

    % Show the map
    subplot(2,3,count)
    count=count+1;
    colormap(cS)
    imagesc(clusterImageMatrix{j},[1,ClusterNumber])
    colorbar
    axis image
    axis off
    cd(dirPath{j})
end
print([NameSaving{j} '_All_Cluster' num2str(ClusterNumber) '.tif'],'-dtiff','-r200')

%% Plot intensity images

% Example of intensity peaks and widths
IntensityPeaks=[1338,1434,1445,1597,1656,2196];
PeakWidths=[...
    10,...
    10,...
    10,...
    10,...
    10,...
    10,...
    10,...
    10];
IntensityRowsPct=cell(1,length(IntensityPeaks));
for j=selectedDatasets
    for i=1:length(IntensityPeaks)
        IntensityRowsTemp=zeros(size(index{j}));
        indexTemp=find(round(Xintvalues)==IntensityPeaks(i));
        for k=1:length(index{j})
            IntensityRowsTemp(k)=trapz(Xintvalues(indexTemp-PeakWidths(i)/2):Xintvalues(indexTemp+PeakWidths(i)/2),...
                DataMatrixNorm(indexTemp-PeakWidths(i)/2:indexTemp+PeakWidths(i)/2,index{j}(k)));
        end
        IntensityRows{j}(:,i)=IntensityRowsTemp;
        IntensityRowsPct{i}=[IntensityRowsPct{i} IntensityRowsTemp]; % For the contrast of the images later
        clear IntensityRowsTemp
    end
end

%% Show them as images

for j=selectedDatasets
    Xmin{j}=min(Xposition{j});
    Xmax{j}=max(Xposition{j});
    Ymin{j}=min(Yposition{j});
    Ymax{j}=max(Yposition{j});
    % Assuming that the step is always the same
    Xstep{j}=Xposition{j}(2)-Xposition{j}(1);
    % Assume that the step is the same in X and Y
    Ystep{j}=Xstep{j};
    % Length of each axis matrix
    Xlength{j}=int16((Xmax{j}-Xmin{j})/Xstep{j})+1;
    Ylength{j}=int16((Ymax{j}-Ymin{j})/Ystep{j})+1;
    Yunique{j}=unique(Yposition{j},'stable');

    % Turn data into a square matrix

    % Prealocating for speed
    IntensityImageMatrix{j}=NaN(Ylength{j},Xlength{j},length(IntensityPeaks));%,size(score,2));
    LengthRow{j}=zeros(length(Yunique{j}),1);
    Rowstart{j}=zeros(length(Yunique{j}),1);
    
    for k=1:length(IntensityPeaks)
        for i=1:length(Yunique{j})
            LengthRow{j}(i)=sum(Yposition{j}==Yunique{j}(i));
            CumLengthRow{j}=cumsum(LengthRow{j});
            % The beginning of the row would be the middle of the length of the
            % row minus half the length of the row
            % Be careful because we are doing snake and not raster!!! (shit)
            Rowstart{j}(i)=round((Xlength{j}-LengthRow{j}(i))/2)+1;
            if i==1
                IntensityImageMatrix{j}(i,Rowstart{j}(i):Rowstart{j}(i)+LengthRow{j}(i)-1,k)=...
                    IntensityRows{j}(1:LengthRow{j}(i),k).';
            elseif mod(i,2)==1
                IntensityImageMatrix{j}(i,Rowstart{j}(i):Rowstart{j}(i)+LengthRow{j}(i)-1,k)=...
                    IntensityRows{j}(CumLengthRow{j}(i-1)+1:CumLengthRow{j}(i-1)+LengthRow{j}(i),k).';        
            else
                if raster(j)==0
                    IntensityImageMatrix{j}(i,Rowstart{j}(i):Rowstart{j}(i)+LengthRow{j}(i)-1,k)=...
                        flip(IntensityRows{j}(CumLengthRow{j}(i-1)+1:CumLengthRow{j}(i-1)+LengthRow{j}(i),k)).';   
                elseif raster(j)==1
                    IntensityImageMatrix{j}(i,Rowstart{j}(i):Rowstart{j}(i)+LengthRow{j}(i)-1,k)=...
                        IntensityRows{j}(CumLengthRow{j}(i-1)+1:CumLengthRow{j}(i-1)+LengthRow{j}(i),k).';               
                end                 
            end
        end
    end
end

%% Exporting the intensity matrix
figure
for j=selectedDatasets
    for i=1:length(IntensityPeaks)
        % Changing the magnification x10 (100% x 10 = 1000) to get 10
        % pixels per normal pixel.
        figure('Name',num2str(IntensityPeaks(i)))
        imshow(IntensityImageMatrix{j}(:,:,i),'Border','tight','InitialMagnification',1000)
        colormap 'gray'
        caxis([prctile(IntensityRowsPct{i},[1 99])])
        waitforbuttonpress
        cd(dirPath{j})
        set(gcf,'PaperPositionMode','auto')
        %print([NameSaving{j} '_All_1-99IntensitySNV_' num2str(IntensityPeaks(i)) '.tif'],'-dtiff','-r0')
        close all
    end
end
close all